# skill-randomness

![Python](https://img.shields.io/badge/python-3.9-blue.svg)
![Python](https://img.shields.io/badge/python-3.10-blue.svg)
![Python](https://img.shields.io/badge/python-3.11-blue.svg)
![Python](https://img.shields.io/badge/python-3.12-blue.svg)
![Python](https://img.shields.io/badge/python-3.13-blue.svg)

## About

A skill for all kinds of chance - make a choice, roll a die, flip a coin, pick between two choices, etc.

Accepts a single property: `die_limit`, which is the maximum number of dice that can be rolled at once. The default is 16.

`~/.config/mycroft/skills/skill-randomness.openvoiceos/settings.json`

```json
{
  "die_limit": 16
}
```

## Examples

- "Flip a coin"
- "Tell me my future"
- "Help me decide something"
- "Pick a number between 1 and 100"
- "Roll a die"
- "Roll 1 d 20"
- "Roll 6 d 8"
- "Roll a 20 sided die"
- "Roll 5 dice"
- "Roll 6, 8 sided dice"

## Credits

- Mike Gray (@mikejgray)
- BuilderJer (@builderjer)

## Category

Games
Fun
Chance

## Tags

ovos skill games fun chance

## Attribution

The coin flipping sound came from [TheKnave at freesound.org](https://freesound.org/people/TheKnave/sounds/435621/). It is licensed under the [Creative Commons 4 License](https://creativecommons.org/licenses/by-nc/4.0/).

The fortune teller sound came from [LittleRainySeasons at freesound.org](https://freesound.org/people/LittleRainySeasons/sounds/335354/). It is licensed under the [Creative Commons 0 License](https://creativecommons.org/publicdomain/zero/1.0/).

The dice rolling sound came from [dermotte at freesound.org](https://freesound.org/people/dermotte/sounds/220741/). It is licensed under the [Creative Commons 4 License](https://creativecommons.org/licenses/by/4.0/).
